.. _mopidy-scan-cmd:

*******************
mopidy-scan command
*******************

Synopsis
========

mopidy-scan
    [-h] [--version] [-q] [-v]


Description
===========

Mopidy is a music server which can play music both from multiple sources, like
your local hard drive, radio streams, and from Spotify and SoundCloud. Searches
combines results from all music sources, and you can mix tracks from all
sources in your play queue. Your playlists from Spotify or SoundCloud are also
available for use.

The ``mopidy-scan`` command is used to index a music library to make it
available for playback with ``mopidy``.


Options
=======

.. program:: mopidy-scan

.. cmdoption:: --version

    Show Mopidy's version number and exit.

.. cmdoption:: -h, --help

    Show help message and exit.

.. cmdoption:: -q, --quiet

    Show less output: warning level and higher.

.. cmdoption:: -v, --verbose

    Show more output: debug level and higher.


See also
========

:ref:`mopidy(1) <mopidy-cmd>`


Reporting bugs
==============

Report bugs to Mopidy's issue tracker at
<https://github.com/mopidy/mopidy/issues>
